// Sample code: load an image, detect the largest face and check whether the face is wearing eye glasses or not
// First image is of a person wearing eye glasses. Second image is of a person not wearing eye glasses.
// The probability that eye glasses of some type are worn over the face is computed in both cases.
// Build on Linux: g++ -o glasses_detection --std=c++11 ./detect_eyeglasses.cpp -I ../ -L ../trueface_sdk -l tf -fopenmp
// Build on macOS: g++ -o glasses_detection --std=c++11 ./detect_eyeglasses.cpp -I ../ -L ../trueface_sdk -l tf

#include "trueface_sdk/tf_sdk.h"
#include <iostream>

int main()
{
    Trueface::SDK tfSdk;
    // TODO: replace the string with your license code.
    bool valid = tfSdk.setLicense("${LICENSE_CODE}");

    if (valid == false)
    {
        std::cout<<"Error: the provided license is invalid."<<std::endl;
        return 1;
    }

    // Load the glases image and detect largest face.
    Trueface::ErrorCode errorCode = tfSdk.setImage("../images/glasses.jpg");
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout<<"Error: could not load the image"<<std::endl;
        return 1;
    }

    Trueface::FaceBoxAndLandmarks faceBoxAndLandmarks;
    bool found = false;
    errorCode = tfSdk.detectLargestFace(faceBoxAndLandmarks, found);

    if (found == false)
    {
        std::cout<<"Error: face not found";
        return 1;
    }

    // Run glasses detection
    Trueface::GlassesLabel glassesLabel;
    float glassesScore;
    errorCode = tfSdk.detectGlasses(faceBoxAndLandmarks, glassesLabel, glassesScore);

    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout<<"Error: could not run glasses detection"<<std::endl;
        return 1;
    }

    if (glassesLabel == Trueface::GlassesLabel::GLASSES)
    {
        std::cout << "Glasses detected" << std::endl;
    }
    else
    {
        std::cout << "No glasses detected" << std::endl;
    }

    // Load the non glasses image and detect largest face.
    errorCode = tfSdk.setImage("../images/headshot.jpg");
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout<<"Error: could not load the image"<<std::endl;
        return 1;
    }

    errorCode = tfSdk.detectLargestFace(faceBoxAndLandmarks, found);

    if (found == false)
    {
        std::cout<<"Error: face not found";
        return 1;
    }

    // Run glasses detection
    errorCode = tfSdk.detectGlasses(faceBoxAndLandmarks, glassesLabel, glassesScore);

    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout<<"Error: could not run glasses detection"<<std::endl;
        return 1;
    }

    if (glassesLabel == Trueface::GlassesLabel::GLASSES)
    {
        std::cout << "Glasses detected" << std::endl;
    }
    else
    {
        std::cout << "No glasses detected" << std::endl;
    }
}